@@ -11,11 +11,11 @@ DateTimeX::Easy - Parse a date/time string using the best method available
 
 =head1 VERSION
 
-Version 0.082
+Version 0.084
 
 =cut
 
-our $VERSION = '0.082';
+our $VERSION = '0.084';
 
 =head1 SYNOPSIS
 
@@ -59,7 +59,7 @@ Currently, DateTimeX::Easy will attempt to parse input in the following order:
 
 =item DateTime - Is the input a DateTime object?
 
-=item ICal - Was DT::F::ICal able to parse the input? (Only works if the package is installed)
+=item ICal - Was DT::F::ICal able to parse the input?
 
 =item DateParse - Was DT::F::DateParse able to parse the input?
 
@@ -73,7 +73,7 @@ Since this module barfs pretty loudly on strange input, we use a silent $SIG{__W
 
 This step also looks at the string to see if there is any timezone information at the end.
 
-=item DateManip - Was DT::F::DateManip able to parse the input? (Only works if package is installed)
+=item DateManip - Was DT::F::DateManip able to parse the input?
 
 DateManip isn't very nice with preserving the input timezone, but it's here as a last resort.
 
@@ -243,13 +243,32 @@ Dave Rolsky and crew for writing L<DateTime>
 
 =head1 SEE ALSO
 
-L<DateTime>, L<DateTime::Format::ICal>, L<DateTime::Format::ParseDate>, L<DateTime::Format::Natural>, L<DateTime::Format::Flexible>,
-L<DateTime::Format::DateManip>, L<Date::Manip>
+L<DateTime>
+
+L<DateTime::Format::Natural>
+
+L<DateTime::Format::Flexible>
+
+L<DateTime::Format::DateManip>
+
+L<DateTime::Format::ParseDate>
+
+L<DateTime::Format::ICal>
+
+L<Date::Manip>
 
 =head1 AUTHOR
 
 Robert Krimen, C<< <rkrimen at cpan.org> >>
 
+=head1 SOURCE
+
+You can contribute or fork this project via GitHub:
+
+L<http://github.com/robertkrimen/datetimex-easy/tree/master>
+
+    git clone git://github.com/robertkrimen/datetimex-easy.git DateTimeX-Easy
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-datetime-easy at rt.cpan.org>, or through
@@ -345,7 +364,11 @@ my %_first_or_last = qw/
     ending      last
 /;
 
-my @_parser_order = qw/DateParse Natural Flexible/;
+my @_parser_order = qw/
+    Flexible
+    DateParse
+    Natural
+/;
 unshift @_parser_order, qw/ICal/ if $have_ICal;
 push @_parser_order, qw/DateManip/ if $have_DateManip;
 my %_parser_source = (
@@ -368,12 +391,36 @@ my %_parser_source = (
         my $parse = shift;
         my $time_zone;
         # First, try to extract out any timezone information
-        if ($parse =~ s/\s+([A-Za-z][A-Za-z0-9\/\._]*)\s*$//) { # Look for a timezone-like string at the end of $parse
-            $time_zone = $1;
-            $parse = "$parse $time_zone" and undef $time_zone if $time_zone && $time_zone =~ m/^[ap]\.?m\.?$/i; # Put back AM/PM if we accidentally slurped it out
-        }
-        elsif ($parse =~ s/\s+([-+]\d{3,})\s*$//) {
-            $time_zone = $1;
+        {
+            ##################################################
+            # 2008-09-16 13:23:57 Eastern Daylight (?:Time)? #
+            ##################################################
+            if ($parse =~ s/\s+(?:(Eastern|Central|Mountain|Pacific)\s+(?:Daylight|Standard)(?:\s+Time)?).*$//) {
+                $time_zone = "US/$1";
+            }
+            ##################################
+            # 2008-09-16 13:23:57 US/Eastern #
+            ##################################
+            elsif ($parse =~ s/\s+([A-Za-z][A-Za-z0-9\/\._]*)\s*$//) { # Look for a timezone-like string at the end of $parse
+                $time_zone = $1;
+                $parse = "$parse $time_zone" and undef $time_zone if $time_zone && $time_zone =~ m/^[ap]\.?m\.?$/i; # Put back AM/PM if we accidentally slurped it out
+            }
+            #########################################################
+            # 2008-09-16 13:23:57 Eastern Daylight Time (GMT+05:00) #
+            #########################################################
+            elsif ($parse =~ s/(?:\s+[A-Z]\w+)*\s+\(?(?:GMT|UTC)?([-+]\d{2}:\d{2})\)?\s*$//) {
+                $time_zone = $1;
+            }
+# Flexible can't seem to parse (GMT+0:500)
+#            elsif ($parse =~ s/(?:\s+[A-Z]\w+)*(\s+\(GMT[-+]\d{2}:\d{2}\)\s*)$//) {
+#                $parse = "$parse $1";
+#            }
+            #############################
+            # 2008-09-16 13:23:57 +0500 #
+            #############################
+            elsif ($parse =~ s/\s+([-+]\d{3,})\s*$//) {
+                $time_zone = $1;
+            }
         }
         return unless my $dt = DateTime::Format::Flexible->build($parse);
         if ($time_zone) {
@@ -471,14 +518,28 @@ sub new {
             my (%parser_exclude);
             %parser_exclude = map { $_ => 1 } (ref $parser_exclude eq "ARRAY" ? @$parser_exclude : ($parser_exclude)) if $parser_exclude;
             my %parser_source = %_parser_source;
+            if (DEBUG) {
+                warn "Parse $parse\n";
+            }
             while (! $parse_dt && @parser_order) {
                 my $parser = shift @parser_order;
                 next if $parser_exclude{$parser};
+                # warn "Try $parser:\n" if DEBUG;
                 my $parser_code = $parser_source{$parser};
                 eval {
                     $parse_dt = $parser_code->($parse);
                 };
-                warn "$parse $parser \$\@: $@" if DEBUG;
+                if (DEBUG) {
+                    if ($@) {
+                        warn "FAIL $parser: $@\n";
+                    }
+                    elsif ($parse_dt) {
+                        warn "PASS $parser: $parse_dt\n"; 
+                    }
+                    else {
+                        warn "FAIL $parser\n";
+                    }
+                }
                 undef $parse_dt if $@;
             }
         }
